#
# spec file for package ghc-base64-bytestring
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name base64-bytestring
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.2.1.0
Release:        3.3
Summary:        Fast base64 encoding and decoding for ByteStrings
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-HUnit-prof
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
BuildRequires:  ghc-test-framework-hunit-prof
BuildRequires:  ghc-test-framework-prof
BuildRequires:  ghc-test-framework-quickcheck2-devel
BuildRequires:  ghc-test-framework-quickcheck2-prof
%endif

%description
This package provides support for encoding and decoding binary data according
to 'base64' (see also <https://tools.ietf.org/html/rfc4648 RFC 4648>) for
strict and lazy ByteStrings

For a fuller-featured and better-performing Base64 library, see the
<https://hackage.haskell.org/package/base64 base64> package.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Wed Jul 12 2023 Peter Simons <psimons@suse.com>
- Update base64-bytestring to version 1.2.1.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Fri Aug 13 2021 psimons@suse.com
- Update base64-bytestring to version 1.2.1.0.
  [#] 1.2.1.0
  * Bugfix for GHC 9.0.1 memory corruption bug ([#46](https://github.com/haskell/base64-bytestring/pull/46))
  * Thanks to [Fraser Tweedale](https://github.com/frasertweedale) and [Andrew Lelechenko](https://github.com/bodigrim) for logging and helping with this fix.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Sun Nov 15 2020 psimons@suse.com
- Update base64-bytestring to version 1.2.0.1.
  [#] 1.2.0.1
  * Package update: support for `bytestring >=0.11`
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Sat Aug 15 2020 psimons@suse.com
- Update base64-bytestring to version 1.2.0.0.
  [#] 1.2.0.0
  * Security fix: reject non-canonical base64 encoded values - ([#38](https://github.com/haskell/base64-bytestring/pull/38)) fixing issue [#24](https://github.com/haskell/base64-bytestring/issues/24).
  * Security fix: reject bytestrings with improper padding that can be "completed" by the unpadded-Base64url workflow, and homogenize error messages ([#33](https://github.com/haskell/base64-bytestring/pull/33))
  * Test coverage expanded to 98%% of the library. All critical paths covered.
* Tue Jun  9 2020 psimons@suse.com
- Update base64-bytestring to version 1.1.0.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/base64-bytestring-1.1.0.0/src/CHANGELOG.md
* Tue Jan 14 2020 psimons@suse.com
- Update base64-bytestring to version 1.0.0.3.
  [#] 1.0.0.3
  * Made performance more robust
    ([#27](https://github.com/haskell/base64-bytestring/pull/27)).
  * Improved documentation
    ([#23](https://github.com/haskell/base64-bytestring/pull/23)).
  * Improved the performance of decodeLenient a bit
    ([#21](https://github.com/haskell/base64-bytestring/pull/21)).
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Wed Dec  5 2018 psimons@suse.com
- Update base64-bytestring to version 1.0.0.2.
  Upstream added a new change log file in this release. With no
  previous version to compare against, the automatic updater cannot
  reliable determine the relevante entries for this release.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Wed May 16 2018 psimons@suse.com
- Prefer the new %%license attribute over %%doc.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.0.0.1 revision 0 with cabal2obs.
* Mon May 13 2013 peter.trommler@ohm-hochschule.de
- new packaging guidelines
  * no macros spanning multiple spec file sections
* Mon May 13 2013 peter.trommler@ohm-hochschule.de
- update to 1.0.0.1 from upstream
- performance improvements
  * encoding 5%%
  * decodeLenient 50%%
* Sun Nov 18 2012 peter.trommler@ohm-hochschule.de
- update to 1.0.0.0 from upstream
  * relaxed version constraints on bytestring
* Wed Oct  3 2012 peter.trommler@ohm-hochschule.de
- update to 0.1.2.0 from upstream
  * fixes joinWith (bug #7)
* Tue Jun  5 2012 peter.trommler@ohm-hochschule.de
- cabal2spec 0.25.5 template for spec file
* Fri Apr 20 2012 peter.trommler@ohm-hochschule.de
- Upgrade to 0.1.1.1 from upstream
  Fix performance regression in encoding.
  The encoding table wasn't being let-floated when URL encoding support was
  added, and so it was being regenerated on every call, with catastrophic
  performance consequences (600x slowdown for small inputs on my machine).
  This fixes gh-4.
* Fri Jan 20 2012 herbert@graeber-clan.de
- initial packaging for Fedora automatically generated by cabal2spec-0.24.1
